aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/core_ext
diff options
context:
space:
mode:
authorJon Rowe <hello@jonrowe.co.uk>2013-04-26 09:02:10 +1000
committerJon Rowe <hello@jonrowe.co.uk>2013-04-26 09:09:53 +1000
commit888f21492a230dd371ff4c88d3130027f32f1d91 (patch)
tree86b6b4a2b9921846347ed9180837770dd974487d /activesupport/lib/active_support/core_ext
parentd495606168f638b272f5775b2a0a796f13ab7c1b (diff)
downloadrails-888f21492a230dd371ff4c88d3130027f32f1d91.tar.gz
rails-888f21492a230dd371ff4c88d3130027f32f1d91.tar.bz2
rails-888f21492a230dd371ff4c88d3130027f32f1d91.zip
better document `next_week` functionaility closes #9568
Diffstat (limited to 'activesupport/lib/active_support/core_ext')
-rw-r--r--activesupport/lib/active_support/core_ext/date_and_time/calculations.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/activesupport/lib/active_support/core_ext/date_and_time/calculations.rb b/activesupport/lib/active_support/core_ext/date_and_time/calculations.rb
index 5b89ace66b..d6c5fac48c 100644
--- a/activesupport/lib/active_support/core_ext/date_and_time/calculations.rb
+++ b/activesupport/lib/active_support/core_ext/date_and_time/calculations.rb
@@ -109,11 +109,11 @@ module DateAndTime
alias :at_beginning_of_year :beginning_of_year
# Returns a new date/time representing the given day in the next week.
- # Week is assumed to start on +start_day+, default is
- # +Date.beginning_of_week+ or +config.beginning_of_week+ when set.
- # DateTime objects have their time set to 0:00.
- def next_week(start_day = Date.beginning_of_week)
- first_hour{ weeks_since(1).beginning_of_week.days_since(days_span(start_day)) }
+ # The +given_day_in_next_week+ defaults to the beginning of the week
+ # which is determined by +Date.beginning_of_week+ or +config.beginning_of_week+
+ # when set. DateTime objects have their time set to 0:00.
+ def next_week(given_day_in_next_week = Date.beginning_of_week)
+ first_hour{ weeks_since(1).beginning_of_week.days_since(days_span(given_day_in_next_week)) }
end
# Short-hand for months_since(1).